@@ -1,9 +1,7 @@
 package Dancer;
-BEGIN {
-  $Dancer::AUTHORITY = 'cpan:SUKRIA';
-}
+our $AUTHORITY = 'cpan:SUKRIA';
 #ABSTRACT: lightweight yet powerful web application framework
-$Dancer::VERSION = '1.3136';
+$Dancer::VERSION = '1.3138';
 use strict;
 use warnings;
 use Carp;
@@ -513,7 +511,7 @@ Dancer - lightweight yet powerful web application framework
 
 =head1 VERSION
 
-version 1.3136
+version 1.3138
 
 =head1 SYNOPSIS
 
