@@ -1,9 +1,7 @@
 package Dancer::App;
-BEGIN {
-  $Dancer::App::AUTHORITY = 'cpan:SUKRIA';
-}
+our $AUTHORITY = 'cpan:SUKRIA';
 # ABSTRACT: Base application class for Dancer.
-$Dancer::App::VERSION = '1.3136';
+$Dancer::App::VERSION = '1.3138';
 use strict;
 use warnings;
 use Carp;
@@ -259,7 +257,7 @@ Dancer::App - Base application class for Dancer.
 
 =head1 VERSION
 
-version 1.3136
+version 1.3138
 
 =head1 AUTHOR
 
