@@ -1,9 +1,7 @@
 package Dancer::Config;
-BEGIN {
-  $Dancer::Config::AUTHORITY = 'cpan:SUKRIA';
-}
+our $AUTHORITY = 'cpan:SUKRIA';
 #ABSTRACT:  how to configure Dancer to suit your needs
-$Dancer::Config::VERSION = '1.3136';
+$Dancer::Config::VERSION = '1.3138';
 use strict;
 use warnings;
 use base 'Exporter';
@@ -38,7 +36,7 @@ my $setters = {
     },
     log_file => sub {
         require Dancer::Logger;
-        Dancer::Logger->init(setting("logger"), setting());
+        Dancer::Logger->init(setting("logger"), settings());
     },
     session => sub {
         my ($setting, $value) = @_;
@@ -185,36 +183,45 @@ sub init_envdir {
 }
 
 sub load {
+
+    my (undef, $extra_config) = @_;
+
     init_confdir();
     init_envdir();
 
     # look for the conffile
-    return 1 unless -f conffile;
+    if (-f conffile) {
 
-    # load YAML
-    my $module = $SETTINGS->{engines}{YAML}{module} || 'YAML';
+        # load YAML
+        my $module = $SETTINGS->{engines}{YAML}{module} || 'YAML';
 
-    my ( $result, $error ) = Dancer::ModuleLoader->load($module);
-    confess "Configuration file found but could not load $module: $error"
-        unless $result;
+        my ( $result, $error ) = Dancer::ModuleLoader->load($module);
+        confess "Configuration file found but could not load $module: $error"
+            unless $result;
+
+        unless ($_LOADED{conffile()}) {
+            load_settings_from_yaml(conffile);
+            $_LOADED{conffile()}++;
+        }
+
+        my $env = environment_file;
+
+        # don't load the same env twice
+        unless( $_LOADED{$env} ) {
+            if (-f $env ) {
+                load_settings_from_yaml($env);
+                $_LOADED{$env}++;
+            }
+            elsif (setting('require_environment')) {
+                # failed to load the env file, and the main config said we needed it.
+                confess "Could not load environment file '$env', and require_environment is set";
+            }
+        }
 
-    unless ($_LOADED{conffile()}) {
-        load_settings_from_yaml(conffile);
-        $_LOADED{conffile()}++;
     }
 
-    my $env = environment_file;
-
-    # don't load the same env twice
-    unless( $_LOADED{$env} ) {
-        if (-f $env ) {
-            load_settings_from_yaml($env);
-            $_LOADED{$env}++;
-        }
-        elsif (setting('require_environment')) {
-            # failed to load the env file, and the main config said we needed it.
-            confess "Could not load environment file '$env', and require_environment is set";
-        }
+    if ($extra_config) {
+        load_settings_from_hashref($extra_config);
     }
 
     foreach my $key (grep { $setters->{$_} } keys %$SETTINGS) {
@@ -227,6 +234,20 @@ sub load {
     return 1;
 }
 
+sub load_settings_from_hashref {
+    my ($config) = @_;
+
+    # exactly like load_settings_from_yaml without the YAML part.
+
+    $SETTINGS = Hash::Merge::Simple::merge( $SETTINGS, {
+        map {
+            $_ => Dancer::Config->normalize_setting( $_, $config->{$_} )
+        } keys %$config
+    } );
+
+    return scalar keys %$config;
+}
+
 sub load_settings_from_yaml {
     my ($file) = @_;
 
@@ -280,7 +301,7 @@ Dancer::Config - how to configure Dancer to suit your needs
 
 =head1 VERSION
 
-version 1.3136
+version 1.3138
 
 =head1 DESCRIPTION
 
@@ -607,31 +628,6 @@ The code throwing that error.
 
 =back
 
-=head3 auto_reload (boolean) (deprecated)
-
-This feature is unmaintained, to be removed in the summer of 2015,
-and B<not working>.
-Use either L<Plack::Loader::Shotgun> or plackup with the -r
-switch:
-
-   plackup -r bin/appl.pl  (will restart the app whenever a file in ./bin or ./lib is modified
-
-Former behaviour was: If set to true, Dancer would reload the route handlers
-whenever the file where they are defined is changed. This is very useful in
-development environment but B<should not be enabled in production>. Enabling
-this flag in production yields a major negative effect on performance because
-of L<Module::Refresh>.
-
-Note that L<Module::Refresh> (similar to plackup -r) only operates on files in
-C<%INC>, so if the script your Dancer app is started from changes, even with
-auto_reload enabled, you will still not see the changes reflected until you start
-your app.
-
-Could also be enabled by setting environment variable L<DANCER_AUTO_RELOAD|/"ENVIRONMENT VARIABLES">
-to a true value or passing --restart=1 to app.pl.
-
-Requires L<Module::Refresh> and L<Clone>.
-
 =head2 Session engine
 
 =head3 session (enum)
