@@ -1,9 +1,7 @@
 package Dancer::Config::Object;
-BEGIN {
-  $Dancer::Config::Object::AUTHORITY = 'cpan:SUKRIA';
-}
+our $AUTHORITY = 'cpan:SUKRIA';
 #ABSTRACT: Access the config via methods instead of hashrefs
-$Dancer::Config::Object::VERSION = '1.3136';
+$Dancer::Config::Object::VERSION = '1.3138';
 use strict;
 use warnings;
 
@@ -107,7 +105,7 @@ Dancer::Config::Object - Access the config via methods instead of hashrefs
 
 =head1 VERSION
 
-version 1.3136
+version 1.3138
 
 =head1 DESCRIPTION
 
