@@ -1,9 +1,7 @@
 package Dancer::Continuation;
-BEGIN {
-  $Dancer::Continuation::AUTHORITY = 'cpan:SUKRIA';
-}
+our $AUTHORITY = 'cpan:SUKRIA';
 # ABSTRACT: Continuation exception (internal exception) for Dancer
-$Dancer::Continuation::VERSION = '1.3136';
+$Dancer::Continuation::VERSION = '1.3138';
 use strict;
 use warnings;
 use Carp;
@@ -31,7 +29,7 @@ Dancer::Continuation - Continuation exception (internal exception) for Dancer
 
 =head1 VERSION
 
-version 1.3136
+version 1.3138
 
 =head1 AUTHOR
 
