@@ -1,9 +1,7 @@
 package Dancer::Continuation::Halted;
-BEGIN {
-  $Dancer::Continuation::Halted::AUTHORITY = 'cpan:SUKRIA';
-}
+our $AUTHORITY = 'cpan:SUKRIA';
 # ABSTRACT: Halted internal exception class for Dancer
-$Dancer::Continuation::Halted::VERSION = '1.3136';
+$Dancer::Continuation::Halted::VERSION = '1.3138';
 use strict;
 use warnings;
 use Carp;
@@ -24,7 +22,7 @@ Dancer::Continuation::Halted - Halted internal exception class for Dancer
 
 =head1 VERSION
 
-version 1.3136
+version 1.3138
 
 =head1 AUTHOR
 
