@@ -1,9 +1,7 @@
 package Dancer::Continuation::Route;
-BEGIN {
-  $Dancer::Continuation::Route::AUTHORITY = 'cpan:SUKRIA';
-}
+our $AUTHORITY = 'cpan:SUKRIA';
 # ABSTRACT: Internal exception class for Route exceptions in Dancer.
-$Dancer::Continuation::Route::VERSION = '1.3136';
+$Dancer::Continuation::Route::VERSION = '1.3138';
 use strict;
 use warnings;
 use Carp;
@@ -28,7 +26,7 @@ Dancer::Continuation::Route - Internal exception class for Route exceptions in D
 
 =head1 VERSION
 
-version 1.3136
+version 1.3138
 
 =head1 METHODS
 
