@@ -1,9 +1,7 @@
 package Dancer::Continuation::Route::Forwarded;
-BEGIN {
-  $Dancer::Continuation::Route::Forwarded::AUTHORITY = 'cpan:SUKRIA';
-}
+our $AUTHORITY = 'cpan:SUKRIA';
 # ABSTRACT: Internal Dancer exception class
-$Dancer::Continuation::Route::Forwarded::VERSION = '1.3136';
+$Dancer::Continuation::Route::Forwarded::VERSION = '1.3138';
 use strict;
 use warnings;
 use Carp;
@@ -24,7 +22,7 @@ Dancer::Continuation::Route::Forwarded - Internal Dancer exception class
 
 =head1 VERSION
 
-version 1.3136
+version 1.3138
 
 =head1 AUTHOR
 
