@@ -1,9 +1,7 @@
 package Dancer::Cookie;
-BEGIN {
-  $Dancer::Cookie::AUTHORITY = 'cpan:SUKRIA';
-}
+our $AUTHORITY = 'cpan:SUKRIA';
 #ABSTRACT: class representing cookies
-$Dancer::Cookie::VERSION = '1.3136';
+$Dancer::Cookie::VERSION = '1.3138';
 use strict;
 use warnings;
 
@@ -134,7 +132,7 @@ Dancer::Cookie - class representing cookies
 
 =head1 VERSION
 
-version 1.3136
+version 1.3138
 
 =head1 SYNOPSIS
 
