@@ -1,9 +1,7 @@
 package Dancer::Deprecation;
-BEGIN {
-  $Dancer::Deprecation::AUTHORITY = 'cpan:SUKRIA';
-}
+our $AUTHORITY = 'cpan:SUKRIA';
 #ABSTRACT: handle deprecation messages
-$Dancer::Deprecation::VERSION = '1.3136';
+$Dancer::Deprecation::VERSION = '1.3138';
 use strict;
 use warnings;
 use Carp;
@@ -48,7 +46,7 @@ Dancer::Deprecation - handle deprecation messages
 
 =head1 VERSION
 
-version 1.3136
+version 1.3138
 
 =head1 SYNOPSIS
 
