@@ -1,9 +1,7 @@
 package Dancer::Error;
-BEGIN {
-  $Dancer::Error::AUTHORITY = 'cpan:SUKRIA';
-}
+our $AUTHORITY = 'cpan:SUKRIA';
 #ABSTRACT: class for representing fatal errors
-$Dancer::Error::VERSION = '1.3136';
+$Dancer::Error::VERSION = '1.3138';
 use strict;
 use warnings;
 use Carp;
@@ -329,7 +327,7 @@ Dancer::Error - class for representing fatal errors
 
 =head1 VERSION
 
-version 1.3136
+version 1.3138
 
 =head1 SYNOPSIS
 
