@@ -1,9 +1,7 @@
 package Dancer::Exception;
-BEGIN {
-  $Dancer::Exception::AUTHORITY = 'cpan:SUKRIA';
-}
+our $AUTHORITY = 'cpan:SUKRIA';
 #ABSTRACT: class for throwing and catching exceptions
-$Dancer::Exception::VERSION = '1.3136';
+$Dancer::Exception::VERSION = '1.3138';
 use strict;
 use warnings;
 use Carp;
@@ -141,7 +139,7 @@ Dancer::Exception - class for throwing and catching exceptions
 
 =head1 VERSION
 
-version 1.3136
+version 1.3138
 
 =head1 SYNOPSIS
 
