@@ -1,9 +1,7 @@
 package Dancer::Exception::Base;
-BEGIN {
-  $Dancer::Exception::Base::AUTHORITY = 'cpan:SUKRIA';
-}
+our $AUTHORITY = 'cpan:SUKRIA';
 #ABSTRACT: the base class of all Dancer exceptions
-$Dancer::Exception::Base::VERSION = '1.3136';
+$Dancer::Exception::Base::VERSION = '1.3138';
 use strict;
 use warnings;
 use Carp;
@@ -109,7 +107,7 @@ Dancer::Exception::Base - the base class of all Dancer exceptions
 
 =head1 VERSION
 
-version 1.3136
+version 1.3138
 
 =head1 DESCRIPTION
 
