@@ -1,9 +1,7 @@
 package Dancer::Factory::Hook;
-BEGIN {
-  $Dancer::Factory::Hook::AUTHORITY = 'cpan:SUKRIA';
-}
+our $AUTHORITY = 'cpan:SUKRIA';
 # ABSTRACT: Singleton class to create Dancer hooks
-$Dancer::Factory::Hook::VERSION = '1.3136';
+$Dancer::Factory::Hook::VERSION = '1.3138';
 use strict;
 use warnings;
 use Carp;
@@ -92,7 +90,7 @@ Dancer::Factory::Hook - Singleton class to create Dancer hooks
 
 =head1 VERSION
 
-version 1.3136
+version 1.3138
 
 =head1 AUTHOR
 
