@@ -1,9 +1,7 @@
 package Dancer::FileUtils;
-BEGIN {
-  $Dancer::FileUtils::AUTHORITY = 'cpan:SUKRIA';
-}
+our $AUTHORITY = 'cpan:SUKRIA';
 #ABSTRACT: helper providing file utilities
-$Dancer::FileUtils::VERSION = '1.3136';
+$Dancer::FileUtils::VERSION = '1.3138';
 use strict;
 use warnings;
 
@@ -159,7 +157,7 @@ Dancer::FileUtils - helper providing file utilities
 
 =head1 VERSION
 
-version 1.3136
+version 1.3138
 
 =head1 SYNOPSIS
 
