@@ -1,9 +1,7 @@
 package Dancer::GetOpt;
-BEGIN {
-  $Dancer::GetOpt::AUTHORITY = 'cpan:SUKRIA';
-}
+our $AUTHORITY = 'cpan:SUKRIA';
 # ABSTRACT: Process command-line options for Dancer scripts
-$Dancer::GetOpt::VERSION = '1.3136';
+$Dancer::GetOpt::VERSION = '1.3138';
 use strict;
 use warnings;
 
@@ -32,7 +30,6 @@ sub process_args {
         'daemon'        => sub { arg_to_setting(@_) },
         'environment=s' => sub { arg_to_setting(@_) },
         'confdir=s'     => sub { arg_to_setting(@_) },
-        'restart=s'     => sub { arg_to_setting( auto_reload => $_[1] ) },
     ) || usage_and_exit();
 
     usage_and_exit() if $help;
@@ -50,7 +47,6 @@ sub print_usage {
    --port=XXXX          Port number to bind to (3000)
    --confdir=PATH       Path the config dir (appdir if not specified)
    --environment=ENV    Environment to use (development)
-   --restart=1|0        Should we restart the application between each request
    --help               Display usage information
 
 OPTIONS
@@ -81,9 +77,6 @@ If not specified, confdir points to appdir.
 
 Which environment to use. By default this value is set to development.
 
---restart
-
-Set the value of the B<auto_reload> setting. DEPRECATED
 
 EOF
 }
@@ -102,7 +95,7 @@ Dancer::GetOpt - Process command-line options for Dancer scripts
 
 =head1 VERSION
 
-version 1.3136
+version 1.3138
 
 =head1 AUTHOR
 
