@@ -1,9 +1,7 @@
 package Dancer::HTTP;
-BEGIN {
-  $Dancer::HTTP::AUTHORITY = 'cpan:SUKRIA';
-}
+our $AUTHORITY = 'cpan:SUKRIA';
 #ABSTRACT: helper for rendering HTTP status codes for Dancer
-$Dancer::HTTP::VERSION = '1.3136';
+$Dancer::HTTP::VERSION = '1.3138';
 use strict;
 use warnings;
 use base 'Exporter';
@@ -101,7 +99,7 @@ Dancer::HTTP - helper for rendering HTTP status codes for Dancer
 
 =head1 VERSION
 
-version 1.3136
+version 1.3138
 
 =head1 DESCRIPTION
 
