@@ -1,9 +1,7 @@
 package Dancer::Handler::Debug;
-BEGIN {
-  $Dancer::Handler::Debug::AUTHORITY = 'cpan:SUKRIA';
-}
+our $AUTHORITY = 'cpan:SUKRIA';
 #ABSTRACT: a debug handler for easy tracing
-$Dancer::Handler::Debug::VERSION = '1.3136';
+$Dancer::Handler::Debug::VERSION = '1.3138';
 use strict;
 use warnings;
 
@@ -86,7 +84,7 @@ Dancer::Handler::Debug - a debug handler for easy tracing
 
 =head1 VERSION
 
-version 1.3136
+version 1.3138
 
 =head1 DESCRIPTION
 
