@@ -1,9 +1,7 @@
 package Dancer::Hook;
-BEGIN {
-  $Dancer::Hook::AUTHORITY = 'cpan:SUKRIA';
-}
+our $AUTHORITY = 'cpan:SUKRIA';
 #ABSTRACT: Class to manipulate hooks with Dancer
-$Dancer::Hook::VERSION = '1.3136';
+$Dancer::Hook::VERSION = '1.3138';
 use strict;
 use warnings;
 use Carp;
@@ -86,7 +84,7 @@ Dancer::Hook - Class to manipulate hooks with Dancer
 
 =head1 VERSION
 
-version 1.3136
+version 1.3138
 
 =head1 SYNOPSIS
 
