@@ -1,9 +1,7 @@
 package Dancer::Hook::Properties;
-BEGIN {
-  $Dancer::Hook::Properties::AUTHORITY = 'cpan:SUKRIA';
-}
+our $AUTHORITY = 'cpan:SUKRIA';
 #ABSTRACT: Properties attached to a hook
-$Dancer::Hook::Properties::VERSION = '1.3136';
+$Dancer::Hook::Properties::VERSION = '1.3138';
 use strict;
 use warnings;
 
@@ -53,7 +51,7 @@ Dancer::Hook::Properties - Properties attached to a hook
 
 =head1 VERSION
 
-version 1.3136
+version 1.3138
 
 =head1 SYNOPSIS
 
