@@ -1,9 +1,7 @@
 package Dancer::Logger;
-BEGIN {
-  $Dancer::Logger::AUTHORITY = 'cpan:SUKRIA';
-}
+our $AUTHORITY = 'cpan:SUKRIA';
 #ABSTRACT: common interface for logging in Dancer
-$Dancer::Logger::VERSION = '1.3136';
+$Dancer::Logger::VERSION = '1.3138';
 # Factory for logger engines
 
 use strict;
@@ -53,7 +51,7 @@ Dancer::Logger - common interface for logging in Dancer
 
 =head1 VERSION
 
-version 1.3136
+version 1.3138
 
 =head1 DESCRIPTION
 
