@@ -1,9 +1,7 @@
 package Dancer::Logger::Abstract;
-BEGIN {
-  $Dancer::Logger::Abstract::AUTHORITY = 'cpan:SUKRIA';
-}
+our $AUTHORITY = 'cpan:SUKRIA';
 #ABSTRACT: Abstract logging engine for Dancer
-$Dancer::Logger::Abstract::VERSION = '1.3136';
+$Dancer::Logger::Abstract::VERSION = '1.3138';
 use strict;
 use warnings;
 use Carp;
@@ -159,7 +157,7 @@ Dancer::Logger::Abstract - Abstract logging engine for Dancer
 
 =head1 VERSION
 
-version 1.3136
+version 1.3138
 
 =head1 SYNOPSIS
 
