@@ -1,9 +1,7 @@
 package Dancer::Logger::Capture::Trap;
-BEGIN {
-  $Dancer::Logger::Capture::Trap::AUTHORITY = 'cpan:SUKRIA';
-}
+our $AUTHORITY = 'cpan:SUKRIA';
 # ABSTRACT: a place to store captured Dancer logs
-$Dancer::Logger::Capture::Trap::VERSION = '1.3136';
+$Dancer::Logger::Capture::Trap::VERSION = '1.3138';
 use base 'Dancer::Object';
 
 
@@ -46,7 +44,7 @@ Dancer::Logger::Capture::Trap - a place to store captured Dancer logs
 
 =head1 VERSION
 
-version 1.3136
+version 1.3138
 
 =head1 SYNOPSIS
 
