@@ -1,9 +1,7 @@
 package Dancer::Logger::File;
-BEGIN {
-  $Dancer::Logger::File::AUTHORITY = 'cpan:SUKRIA';
-}
+our $AUTHORITY = 'cpan:SUKRIA';
 #ABSTRACT: file-based logging engine for Dancer
-$Dancer::Logger::File::VERSION = '1.3136';
+$Dancer::Logger::File::VERSION = '1.3138';
 use strict;
 use warnings;
 use Carp;
@@ -101,7 +99,7 @@ Dancer::Logger::File - file-based logging engine for Dancer
 
 =head1 VERSION
 
-version 1.3136
+version 1.3138
 
 =head1 SYNOPSIS
 
