@@ -1,9 +1,7 @@
 package Dancer::MIME;
-BEGIN {
-  $Dancer::MIME::AUTHORITY = 'cpan:SUKRIA';
-}
+our $AUTHORITY = 'cpan:SUKRIA';
 #ABSTRACT: Singleton object to handle MimeTypes
-$Dancer::MIME::VERSION = '1.3136';
+$Dancer::MIME::VERSION = '1.3138';
 use strict;
 use warnings;
 use base 'Dancer::Object::Singleton';
@@ -82,7 +80,7 @@ Dancer::MIME - Singleton object to handle MimeTypes
 
 =head1 VERSION
 
-version 1.3136
+version 1.3138
 
 =head1 SYNOPSIS
 
