@@ -1,9 +1,7 @@
 package Dancer::Object;
-BEGIN {
-  $Dancer::Object::AUTHORITY = 'cpan:SUKRIA';
-}
+our $AUTHORITY = 'cpan:SUKRIA';
 #ABSTRACT: Objects base class for Dancer
-$Dancer::Object::VERSION = '1.3136';
+$Dancer::Object::VERSION = '1.3138';
 # This class is a root class for each object in Dancer.
 # It provides basic OO tools for Perl5 without being... Moose ;-)
 
@@ -114,7 +112,7 @@ Dancer::Object - Objects base class for Dancer
 
 =head1 VERSION
 
-version 1.3136
+version 1.3138
 
 =head1 SYNOPSIS
 
