@@ -1,9 +1,7 @@
 package Dancer::Plugin;
-BEGIN {
-  $Dancer::Plugin::AUTHORITY = 'cpan:SUKRIA';
-}
+our $AUTHORITY = 'cpan:SUKRIA';
 #ABSTRACT: helper for writing Dancer plugins
-$Dancer::Plugin::VERSION = '1.3136';
+$Dancer::Plugin::VERSION = '1.3138';
 use strict;
 use warnings;
 use Carp;
@@ -126,7 +124,7 @@ Dancer::Plugin - helper for writing Dancer plugins
 
 =head1 VERSION
 
-version 1.3136
+version 1.3138
 
 =head1 SYNOPSIS
 
