@@ -1,9 +1,7 @@
 package Dancer::Renderer;
-BEGIN {
-  $Dancer::Renderer::AUTHORITY = 'cpan:SUKRIA';
-}
+our $AUTHORITY = 'cpan:SUKRIA';
 # ABSTRACT: Rendering class for Dancer
-$Dancer::Renderer::VERSION = '1.3136';
+$Dancer::Renderer::VERSION = '1.3138';
 use strict;
 use warnings;
 use Carp;
@@ -333,7 +331,7 @@ Dancer::Renderer - Rendering class for Dancer
 
 =head1 VERSION
 
-version 1.3136
+version 1.3138
 
 =head1 AUTHOR
 
