@@ -1,9 +1,7 @@
 package Dancer::Request;
-BEGIN {
-  $Dancer::Request::AUTHORITY = 'cpan:SUKRIA';
-}
+our $AUTHORITY = 'cpan:SUKRIA';
 #ABSTRACT: interface for accessing incoming requests
-$Dancer::Request::VERSION = '1.3136';
+$Dancer::Request::VERSION = '1.3138';
 use strict;
 use warnings;
 use Carp;
@@ -623,7 +621,7 @@ Dancer::Request - interface for accessing incoming requests
 
 =head1 VERSION
 
-version 1.3136
+version 1.3138
 
 =head1 DESCRIPTION
 
