@@ -1,9 +1,7 @@
 package Dancer::Request::Upload;
-BEGIN {
-  $Dancer::Request::Upload::AUTHORITY = 'cpan:SUKRIA';
-}
+our $AUTHORITY = 'cpan:SUKRIA';
 #ABSTRACT: class representing file uploads requests
-$Dancer::Request::Upload::VERSION = '1.3136';
+$Dancer::Request::Upload::VERSION = '1.3138';
 use File::Spec;
 use Carp;
 
@@ -88,7 +86,7 @@ Dancer::Request::Upload - class representing file uploads requests
 
 =head1 VERSION
 
-version 1.3136
+version 1.3138
 
 =head1 SYNOPSIS
 
