@@ -1,9 +1,7 @@
 package Dancer::Response;
-BEGIN {
-  $Dancer::Response::AUTHORITY = 'cpan:SUKRIA';
-}
+our $AUTHORITY = 'cpan:SUKRIA';
 #ABSTRACT: Response object for Dancer
-$Dancer::Response::VERSION = '1.3136';
+$Dancer::Response::VERSION = '1.3138';
 use strict;
 use warnings;
 use Carp;
@@ -199,7 +197,7 @@ Dancer::Response - Response object for Dancer
 
 =head1 VERSION
 
-version 1.3136
+version 1.3138
 
 =head1 SYNOPSIS
 
