@@ -1,9 +1,7 @@
 package Dancer::Route::Cache;
-BEGIN {
-  $Dancer::Route::Cache::AUTHORITY = 'cpan:SUKRIA';
-}
+our $AUTHORITY = 'cpan:SUKRIA';
 #ABSTRACT: route caching mechanism for L<Dancer>
-$Dancer::Route::Cache::VERSION = '1.3136';
+$Dancer::Route::Cache::VERSION = '1.3138';
 use strict;
 use warnings;
 use Carp;
@@ -157,7 +155,7 @@ Dancer::Route::Cache - route caching mechanism for L<Dancer>
 
 =head1 VERSION
 
-version 1.3136
+version 1.3138
 
 =head1 SYNOPSIS
 
