@@ -1,9 +1,7 @@
 package Dancer::Route::Registry;
-BEGIN {
-  $Dancer::Route::Registry::AUTHORITY = 'cpan:SUKRIA';
-}
+our $AUTHORITY = 'cpan:SUKRIA';
 # ABSTRACT: Route registry for Dancer
-$Dancer::Route::Registry::VERSION = '1.3136';
+$Dancer::Route::Registry::VERSION = '1.3138';
 use strict;
 use warnings;
 use Carp;
@@ -161,7 +159,7 @@ Dancer::Route::Registry - Route registry for Dancer
 
 =head1 VERSION
 
-version 1.3136
+version 1.3138
 
 =head1 AUTHOR
 
