@@ -1,9 +1,7 @@
 package Dancer::Serializer;
-BEGIN {
-  $Dancer::Serializer::AUTHORITY = 'cpan:SUKRIA';
-}
+our $AUTHORITY = 'cpan:SUKRIA';
 #ABSTRACT: serializer wrapper for Dancer
-$Dancer::Serializer::VERSION = '1.3136';
+$Dancer::Serializer::VERSION = '1.3138';
 # Factory for serializer engines
 
 use strict;
@@ -135,7 +133,7 @@ Dancer::Serializer - serializer wrapper for Dancer
 
 =head1 VERSION
 
-version 1.3136
+version 1.3138
 
 =head1 DESCRIPTION
 
