@@ -1,9 +1,7 @@
 package Dancer::Serializer::Abstract;
-BEGIN {
-  $Dancer::Serializer::Abstract::AUTHORITY = 'cpan:SUKRIA';
-}
+our $AUTHORITY = 'cpan:SUKRIA';
 # ABSTRACT: Base serialiser class for Dancer
-$Dancer::Serializer::Abstract::VERSION = '1.3136';
+$Dancer::Serializer::Abstract::VERSION = '1.3138';
 use strict;
 use warnings;
 use Carp;
@@ -43,7 +41,7 @@ Dancer::Serializer::Abstract - Base serialiser class for Dancer
 
 =head1 VERSION
 
-version 1.3136
+version 1.3138
 
 =head1 AUTHOR
 
