@@ -1,9 +1,7 @@
 package Dancer::Serializer::Dumper;
-BEGIN {
-  $Dancer::Serializer::Dumper::AUTHORITY = 'cpan:SUKRIA';
-}
+our $AUTHORITY = 'cpan:SUKRIA';
 # ABSTRACT: Data::Dumper serialisation for Dancer
-$Dancer::Serializer::Dumper::VERSION = '1.3136';
+$Dancer::Serializer::Dumper::VERSION = '1.3138';
 use strict;
 use warnings;
 use Carp;
@@ -54,7 +52,7 @@ Dancer::Serializer::Dumper - Data::Dumper serialisation for Dancer
 
 =head1 VERSION
 
-version 1.3136
+version 1.3138
 
 =head1 AUTHOR
 
