@@ -1,8 +1,6 @@
 package Dancer::Serializer::JSONP;
-BEGIN {
-  $Dancer::Serializer::JSONP::AUTHORITY = 'cpan:SUKRIA';
-}
-$Dancer::Serializer::JSONP::VERSION = '1.3136';
+our $AUTHORITY = 'cpan:SUKRIA';
+$Dancer::Serializer::JSONP::VERSION = '1.3138';
 # ABSTRACT: serializer for handling JSONP data
 
 use strict;
@@ -36,7 +34,7 @@ Dancer::Serializer::JSONP - serializer for handling JSONP data
 
 =head1 VERSION
 
-version 1.3136
+version 1.3138
 
 =head1 SYNOPSIS
 
