@@ -1,9 +1,7 @@
 package Dancer::Serializer::XML;
-BEGIN {
-  $Dancer::Serializer::XML::AUTHORITY = 'cpan:SUKRIA';
-}
+our $AUTHORITY = 'cpan:SUKRIA';
 #ABSTRACT: serializer for handling XML data
-$Dancer::Serializer::XML::VERSION = '1.3136';
+$Dancer::Serializer::XML::VERSION = '1.3138';
 use strict;
 use warnings;
 use Carp;
@@ -93,7 +91,7 @@ Dancer::Serializer::XML - serializer for handling XML data
 
 =head1 VERSION
 
-version 1.3136
+version 1.3138
 
 =head1 SYNOPSIS
 
