@@ -1,9 +1,7 @@
 package Dancer::Serializer::YAML;
-BEGIN {
-  $Dancer::Serializer::YAML::AUTHORITY = 'cpan:SUKRIA';
-}
+our $AUTHORITY = 'cpan:SUKRIA';
 #ABSTRACT: serializer for handling YAML data
-$Dancer::Serializer::YAML::VERSION = '1.3136';
+$Dancer::Serializer::YAML::VERSION = '1.3138';
 use strict;
 use warnings;
 use Carp;
@@ -69,7 +67,7 @@ Dancer::Serializer::YAML - serializer for handling YAML data
 
 =head1 VERSION
 
-version 1.3136
+version 1.3138
 
 =head1 SYNOPSIS
 
