@@ -1,9 +1,7 @@
 package Dancer::Session;
-BEGIN {
-  $Dancer::Session::AUTHORITY = 'cpan:SUKRIA';
-}
+our $AUTHORITY = 'cpan:SUKRIA';
 #ABSTRACT: session engine for the Dancer framework
-$Dancer::Session::VERSION = '1.3136';
+$Dancer::Session::VERSION = '1.3138';
 use strict;
 use warnings;
 
@@ -83,7 +81,7 @@ Dancer::Session - session engine for the Dancer framework
 
 =head1 VERSION
 
-version 1.3136
+version 1.3138
 
 =head1 DESCRIPTION
 
