@@ -1,9 +1,7 @@
 package Dancer::Session::Abstract;
-BEGIN {
-  $Dancer::Session::Abstract::AUTHORITY = 'cpan:SUKRIA';
-}
+our $AUTHORITY = 'cpan:SUKRIA';
 #ABSTRACT: abstract class for session engine
-$Dancer::Session::Abstract::VERSION = '1.3136';
+$Dancer::Session::Abstract::VERSION = '1.3138';
 use strict;
 use warnings;
 use Carp;
@@ -146,7 +144,7 @@ Dancer::Session::Abstract - abstract class for session engine
 
 =head1 VERSION
 
-version 1.3136
+version 1.3138
 
 =head1 DESCRIPTION
 
