@@ -1,9 +1,7 @@
 package Dancer::Session::Simple;
-BEGIN {
-  $Dancer::Session::Simple::AUTHORITY = 'cpan:SUKRIA';
-}
+our $AUTHORITY = 'cpan:SUKRIA';
 #ABSTRACT: in-memory session backend for Dancer
-$Dancer::Session::Simple::VERSION = '1.3136';
+$Dancer::Session::Simple::VERSION = '1.3138';
 use strict;
 use warnings;
 use base 'Dancer::Session::Abstract';
@@ -53,7 +51,7 @@ Dancer::Session::Simple - in-memory session backend for Dancer
 
 =head1 VERSION
 
-version 1.3136
+version 1.3138
 
 =head1 DESCRIPTION
 
