@@ -1,9 +1,7 @@
 package Dancer::SharedData;
-BEGIN {
-  $Dancer::SharedData::AUTHORITY = 'cpan:SUKRIA';
-}
+our $AUTHORITY = 'cpan:SUKRIA';
 # ABSTRACT: Shared-data singleton for Dancer
-$Dancer::SharedData::VERSION = '1.3136';
+$Dancer::SharedData::VERSION = '1.3138';
 use strict;
 use warnings;
 use Dancer::Timer;
@@ -90,7 +88,7 @@ Dancer::SharedData - Shared-data singleton for Dancer
 
 =head1 VERSION
 
-version 1.3136
+version 1.3138
 
 =head1 AUTHOR
 
