@@ -1,9 +1,7 @@
 package Dancer::Template;
-BEGIN {
-  $Dancer::Template::AUTHORITY = 'cpan:SUKRIA';
-}
+our $AUTHORITY = 'cpan:SUKRIA';
 #ABSTRACT: template wrapper for Dancer
-$Dancer::Template::VERSION = '1.3136';
+$Dancer::Template::VERSION = '1.3138';
 use strict;
 use warnings;
 use Dancer::ModuleLoader;
@@ -35,7 +33,7 @@ Dancer::Template - template wrapper for Dancer
 
 =head1 VERSION
 
-version 1.3136
+version 1.3138
 
 =head1 DESCRIPTION
 
