@@ -1,9 +1,7 @@
 package Dancer::Template::Abstract;
-BEGIN {
-  $Dancer::Template::Abstract::AUTHORITY = 'cpan:SUKRIA';
-}
+our $AUTHORITY = 'cpan:SUKRIA';
 #ABSTRACT: abstract class for Dancer's template engines
-$Dancer::Template::Abstract::VERSION = '1.3136';
+$Dancer::Template::Abstract::VERSION = '1.3138';
 use strict;
 use warnings;
 use Carp;
@@ -222,7 +220,7 @@ Dancer::Template::Abstract - abstract class for Dancer's template engines
 
 =head1 VERSION
 
-version 1.3136
+version 1.3138
 
 =head1 DESCRIPTION
 
