@@ -1,9 +1,7 @@
 package Dancer::Template::TemplateToolkit;
-BEGIN {
-  $Dancer::Template::TemplateToolkit::AUTHORITY = 'cpan:SUKRIA';
-}
+our $AUTHORITY = 'cpan:SUKRIA';
 #ABSTRACT: Template Toolkit wrapper for Dancer
-$Dancer::Template::TemplateToolkit::VERSION = '1.3136';
+$Dancer::Template::TemplateToolkit::VERSION = '1.3138';
 use strict;
 use warnings;
 use Carp;
@@ -83,6 +81,46 @@ sub init {
     $_engine = $class->new(%$tt_config);
 }
 
+sub set_wrapper {
+	my ($self, $when, $file) = @_;
+	my $wrappers = $_engine->{SERVICE}->{WRAPPER};
+	unless (defined $file) {
+		$file = $when;
+		my @orig = @$wrappers;
+        $self->{orig_wrappers} = \@orig;
+		@$wrappers = ($file);
+        return;
+	}
+	if ($when eq 'outer') {
+        unshift @$wrappers => $file;
+    } elsif ($when eq 'inner') {
+        push @$wrappers => $file;
+    } else {
+        raise core_template => "'$when' isn't a valid identifier";
+    }
+}
+
+sub reset_wrapper {
+    my ($self) = @_;
+	my $wrappers = $_engine->{SERVICE}->{WRAPPER};
+    my $orig = $self->{orig_wrappers} || [];
+    my @old = @$wrappers;
+    @$wrappers = @$orig;
+    return @old;
+}
+
+sub unset_wrapper {
+    my ($self, $when) = @_;
+	my $wrappers = $_engine->{SERVICE}->{WRAPPER};
+	if ($when eq 'outer') {
+        return shift @$wrappers;
+    } elsif ($when eq 'inner') {
+        return pop @$wrappers;
+    } else {
+        raise core_template => "'$when' isn't a valid identifier";
+    }
+}
+
 sub render {
     my ($self, $template, $tokens) = @_;
 
@@ -135,7 +173,7 @@ Dancer::Template::TemplateToolkit - Template Toolkit wrapper for Dancer
 
 =head1 VERSION
 
-version 1.3136
+version 1.3138
 
 =head1 DESCRIPTION
 
@@ -244,21 +282,46 @@ To enable this:
 This feature requires L<Template::Provider::FromDATA>. Put your templates in the
 __DATA__ section, and start every template with __${templatename}__.
 
+=head1 USING TT'S WRAPPER STACK
+
+This engine provides three additional methods to access the WRAPPER stack of
+TemplateToolkit.
+
+=head2 set_wrapper
+
+Synopsis:
+
+    engine('template')->set_wrapper( inner => 'inner_layout.tt' );
+    engine('template')->set_wrapper( outer => 'outer_layout.tt' );
+    engine('template')->set_wrapper( 'only_layout.tt' );
+
+The first two lines pushes/unshifts layout files to the wrapper array.
+The third line overwrites the wrapper array with a single element.
+
+=head2 unset_wrapper
+
+Synopsis:
+
+    engine('template')->unset_wrapper('inner') # returns 'inner_layout.tt';
+    engine('template')->unset_wrapper('outer') # returns 'outer_layout.tt';
+
+These lines pops/shifts layout files from the wrapper array and returns the
+removed elements.
+
+=head2 reset_wrapper
+
+Synopsis:
+
+    engine('template')->reset_wrapper;
+
+This method restores the wrapper array after a set_wrapper call.
+
 =head1 SEE ALSO
 
 L<Dancer>, L<Template>
 
 =head1 AUTHOR
 
-This module has been written by Alexis Sukrieh
-
-=head1 LICENSE
-
-This module is free software and is released under the same terms as Perl
-itself.
-
-=head1 AUTHOR
-
 Dancer Core Developers
 
 =head1 COPYRIGHT AND LICENSE
